# Peri.dot ([1.1](https://github.com/toto-bird/Peri.dot/releases/tag/1.1.1))

![Peri.dot Logo](https://raw.githubusercontent.com/toto-bird/Peri.dot/master/logo.png)


[Homepage](https://toto-bird.github.io/Peri.dot-lang/)<br />
[Documentation](https://toto-bird.github.io/Peri.dot-lang/docs)<br />
[Playground](https://toto-bird.github.io/Peri.dot-lang/playground)<br />